Mixed-Up Code Exercises
------------------------

.. selectquestion:: obj_mixedupcode_1_sq
   :fromid: obj_mixedupcode_1, obj_mixedupcode_1_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_2_v2_sq
   :fromid: obj_mixedupcode_2_v2, obj_mixedupcode_2_v2_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_3_sq
   :fromid: obj_mixedupcode_3, obj_mixedupcode_3_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_4_sq
   :fromid: obj_mixedupcode_4, obj_mixedupcode_4_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_5_v3_sq
   :fromid: obj_mixedupcode_5_v3, obj_mixedupcode_5_v3_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_6_sq
   :fromid: obj_mixedupcode_6, obj_mixedupcode_6_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_7_v2_sq
   :fromid: obj_mixedupcode_7_v2, obj_mixedupcode_7_v2_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_8_sq
   :fromid: obj_mixedupcode_8, obj_mixedupcode_8_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_9_sq
   :fromid: obj_mixedupcode_9, obj_mixedupcode_9_ac
   :toggle:

.. selectquestion:: obj_mixedupcode_10_sq
   :fromid: obj_mixedupcode_10, obj_mixedupcode_10_ac
   :toggle:
